--[[
 	This dialog is designed to be used by the plugin author only.  If you use this dialog to creat annotations, they will be overwritten by
	any default annotations that are included in the next update.

	This dialog allows rapid creation of default annotations by selecting the map, annotation type and custom value then when the user clicks
	the "Add" button, the text to create an annotation at the user's coordinates with the text of the users's target will be added to the 
	textboxes on the Annotations and Resources tabs.

	The lock on the Type list only affects the query button.  If the type is locked, the query will fill all available fields but will not try
	to resolve the type. This is handy when processing a lot of undetectable types like NPCs.

]]--
DefaultAnnotationsMaker = class(Turbine.UI.Lotro.Window);
function DefaultAnnotationsMaker:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self );
	self:SetText("Default Annotations Maker");
	self:SetVisible(false);
	self:SetSize(550,600);
	self:SetPosition((Turbine.UI.Display:GetWidth() - self:GetWidth()) / 2,(Turbine.UI.Display:GetHeight() - self:GetHeight()) / 2);

	self.SettingsTab=Turbine.UI.Control();
	self.SettingsTab:SetParent(self);
	self.SettingsTab:SetPosition(10,40);
	self.SettingsTab:SetSize(self:GetWidth()-20,self:GetHeight()-80);
	self.SettingsTab:SetBackColor(Turbine.UI.Color(0,0,0));

	self.StringIndexCaption=Turbine.UI.Label();
	self.StringIndexCaption:SetParent(self.SettingsTab);
	self.StringIndexCaption:SetPosition(0,0);
	self.StringIndexCaption:SetSize(90,20);
	self.StringIndexCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.StringIndexCaption:SetForeColor(fontColor);
	self.StringIndexCaption:SetText("Index:");
	self.StringIndexCaption:SetMouseVisible(false);
	self.StringIndexText=Turbine.UI.Lotro.TextBox();
	self.StringIndexText:SetParent(self.SettingsTab);
	self.StringIndexText:SetSize(80,20);
	self.StringIndexText:SetPosition(90,self.StringIndexCaption:GetTop());
	self.StringIndexText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.StringIndexText:SetText("1");

	self.MapCaption=Turbine.UI.Label();
	self.MapCaption:SetParent(self.SettingsTab);
	self.MapCaption:SetPosition(0,self.StringIndexCaption:GetTop()+25);
	self.MapCaption:SetSize(90,20);
	self.MapCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.MapCaption:SetForeColor(fontColor);
	self.MapCaption:SetText("Map:");
	self.MapCaption:SetMouseVisible(false);
	self.MapSelect=GaranStuff.MoorMap.DropDownList()
	self.MapSelect:SetParent(self.SettingsTab);
	self.MapSelect:SetSize(300,20);
	self.MapSelect:SetPosition(90,self.MapCaption:GetTop());
	self.MapSelect:SetBorderColor(trimColor);
	self.MapSelect:SetBackColor(backColor);
	self.MapSelect.CurrentValue:SetBackColor(backColor);
	self.MapSelect:SetTextColor(listTextColor);
	self.MapSelect:SetDropRows(15);

	for tmpIndex=1,#mapInfo do
		self.MapSelect:AddItem(Resource[1][mapInfo[tmpIndex][2]],tmpIndex)
	end

	self.MapSelect:SetSelectedIndex(1);
	self.MapSelect.SelectedIndexChanged=function()
	end

	self.TypeCaption=Turbine.UI.Label();
	self.TypeCaption:SetParent(self.SettingsTab);
	self.TypeCaption:SetPosition(0,self.MapCaption:GetTop()+25);
	self.TypeCaption:SetSize(90,18);
	self.TypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.TypeCaption:SetForeColor(fontColor);
	self.TypeCaption:SetText("Type:");
	self.TypeCaption:SetMouseVisible(false);

	self.TypeList=GaranStuff.MoorMap.DropDownList();
	self.TypeList:SetParent(self.SettingsTab);
	self.TypeList:SetPosition(90,self.TypeCaption:GetTop());
	self.TypeList:SetSize(300,20);
	self.TypeList:SetBorderColor(trimColor);
	self.TypeList:SetCurrentBackColor(colorDarkGrey);
	self.TypeList:SetBackColor(backColor);
	self.TypeList:SetCurrentBackColor(backColor);
	self.TypeList:SetDropRows(5);

	for tmpIndex=1,#iconInfo do
		self.TypeList:AddItem(Resource[1][iconInfo[tmpIndex][1]],tmpIndex);
	end
	self.TypeList:SetSelectedIndex(1);
	self.TypeList.SelectedIndexChanged=function()
	end

	self.TypeList:SetZOrder(80);
	self.MapSelect:SetZOrder(85);

	self.TypeLock=Turbine.UI.Control();
	self.TypeLock:SetParent(self.SettingsTab);
	self.TypeLock:SetPosition(self.TypeList:GetLeft()+self.TypeList:GetWidth()+5,self.TypeList:GetTop());
	self.TypeLock:SetSize(20,20);
	self.TypeLock:SetBlendMode(Turbine.UI.BlendMode.Overlay);
	self.TypeLock:SetBackground(0x410001cf); --0x410001d0= locked
	self.TypeLock.Locked=false;
	self.TypeLock.MouseClick=function()
		self.TypeLock.Locked=not self.TypeLock.Locked;
		if self.TypeLock.Locked then
			self.TypeLock:SetBackground(0x410001d0);
		else
			self.TypeLock:SetBackground(0x410001cf);
		end
	end

	self.NameCaption=Turbine.UI.Label();
	self.NameCaption:SetParent(self.SettingsTab);
	self.NameCaption:SetPosition(0,self.TypeCaption:GetTop()+25);
	self.NameCaption:SetSize(90,18);
	self.NameCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.NameCaption:SetForeColor(fontColor);
	self.NameCaption:SetText("Name:");
	self.NameCaption:SetMouseVisible(false);
	self.NameText=Turbine.UI.Lotro.TextBox();
	self.NameText:SetParent(self.SettingsTab);
	self.NameText:SetPosition(90,self.NameCaption:GetTop());
	self.NameText:SetSize(250,18);
	self.NameText:SetFont(Turbine.UI.Lotro.Font.Verdana16);
	self.NameText:SetMultiline(false);

	self.DescriptionCaption=Turbine.UI.Label();
	self.DescriptionCaption:SetParent(self.SettingsTab);
	self.DescriptionCaption:SetPosition(0,self.NameCaption:GetTop()+25);
	self.DescriptionCaption:SetSize(90,18);
	self.DescriptionCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.DescriptionCaption:SetForeColor(fontColor);
	self.DescriptionCaption:SetText("Descrip.:");
	self.DescriptionCaption:SetMouseVisible(false);
	self.DescriptionText=Turbine.UI.Lotro.TextBox();
	self.DescriptionText:SetParent(self.SettingsTab);
	self.DescriptionText:SetPosition(90,self.DescriptionCaption:GetTop());
	self.DescriptionText:SetSize(440,72);
	self.DescriptionText:SetFont(Turbine.UI.Lotro.Font.Verdana16);
	self.DescriptionText:SetMultiline(true);

	self.NSCoordCaption=Turbine.UI.Label();
	self.NSCoordCaption:SetParent(self.SettingsTab);
	self.NSCoordCaption:SetPosition(0,self.DescriptionCaption:GetTop()+25+54);
	self.NSCoordCaption:SetSize(90,18);
	self.NSCoordCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.NSCoordCaption:SetForeColor(fontColor);
	self.NSCoordCaption:SetText("N/S:");
	self.NSCoordCaption:SetMouseVisible(false);
	self.NSCoordText=Turbine.UI.Lotro.TextBox();
	self.NSCoordText:SetParent(self.SettingsTab);
	self.NSCoordText:SetPosition(90,self.NSCoordCaption:GetTop());
	self.NSCoordText:SetSize(45,18);
	self.NSCoordText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);

	self.NSButtons=GaranStuff.MoorMap.RadioButtonGroup();
	self.NSButtons:SetParent(self.SettingsTab);
	self.NSButtons:SetSize(90,20);
	self.NSButtons:SetPosition(140,self.NSCoordCaption:GetTop());
	self.NSButtons.UnselectedIcon="GaranStuff/MoorMap/Resources/RB_unselected.tga";
	self.NSButtons.SelectedIcon="GaranStuff/MoorMap/Resources/RB_selected.tga";
	self.NSButtons.IconWidth=16;
	self.NSButtons.IconHeight=16;
	self.NSButtons:SetBorderColor(backColor);
	self.NSButtons:SetBackColor(backColor);
	self.NSButtons:SetTextColor(fontColor);
	self.NSButtons:AddChoice("N");
	self.NSButtons:AddChoice("S");
	self.NSButtons:SetRows(1);
	self.NSButtons:SetSelectedChoice(2);
	self.NSButtons.SelectionChanged=function()
	end

	-- quickslot to execute the command "/loc"
	self.refineLocContainer=Turbine.UI.Control();
	self.refineLocContainer:SetParent(self.SettingsTab);
	self.refineLocContainer:SetSize(32,32);
	self.refineLocContainer:SetPosition(self.NSButtons:GetLeft()+self.NSButtons:GetWidth()+5,self.NSButtons:GetTop());
	self.refineLoc=Turbine.UI.Lotro.Quickslot();
	self.refineLoc:SetParent(self.refineLocContainer);
	self.refineLoc:SetSize(66,66);
	self.refineLoc:SetPosition(-34,-34);
	self.refineLoc:SetAllowDrop(false);
	self.refineLoc:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, "/loc"))
	self.refineLoc:SetVisible(true);
	self.refineLocIcon=Turbine.UI.Control();
	self.refineLocIcon:SetParent(self.refineLocContainer);
	self.refineLocIcon:SetPosition(0,0);
	self.refineLocIcon:SetBackground(0x41007f48);
	self.refineLocIcon:SetSize(12,12);
	self.refineLocIcon:SetStretchMode(2);
	self.refineLocIcon:SetSize(32,32);
--	self.refineLocIcon:SetBlendMode(Turbine.UI.BlendMode.Overlay);
	self.refineLocIcon:SetMouseVisible(false);
	self.refineLocIcon:SetVisible(true);

	self.refineLoc.MouseUp=function(sender,args)
		self.refineLoc:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, "/loc"))
		self.refineLoc:SetVisible(true);
	end

	self.EWCoordCaption=Turbine.UI.Label();
	self.EWCoordCaption:SetParent(self.SettingsTab);
	self.EWCoordCaption:SetPosition(0,self.NSCoordCaption:GetTop()+25);
	self.EWCoordCaption:SetSize(90,18);
	self.EWCoordCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.EWCoordCaption:SetForeColor(fontColor);
	self.EWCoordCaption:SetText("E/W:");
	self.EWCoordCaption:SetMouseVisible(false);
	self.EWCoordText=Turbine.UI.Lotro.TextBox();
	self.EWCoordText:SetParent(self.SettingsTab);
	self.EWCoordText:SetPosition(90,self.EWCoordCaption:GetTop());
	self.EWCoordText:SetSize(45,18);
	self.EWCoordText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);

	self.EWButtons=GaranStuff.MoorMap.RadioButtonGroup();
	self.EWButtons:SetParent(self.SettingsTab);
	self.EWButtons:SetSize(90,20);
	self.EWButtons:SetPosition(140,self.EWCoordCaption:GetTop());
	self.EWButtons.UnselectedIcon="GaranStuff/MoorMap/Resources/RB_unselected.tga";
	self.EWButtons.SelectedIcon="GaranStuff/MoorMap/Resources/RB_selected.tga";
	self.EWButtons.IconWidth=16;
	self.EWButtons.IconHeight=16;
	self.EWButtons:SetBorderColor(backColor);
	self.EWButtons:SetBackColor(backColor);
	self.EWButtons:SetTextColor(fontColor);
	self.EWButtons:AddChoice("E");
	self.EWButtons:AddChoice("W");
	self.EWButtons:SetRows(1);
	self.EWButtons:SetSelectedChoice(2);
	self.EWButtons.SelectionChanged=function()
	end


	self.AllegianceCaption=Turbine.UI.Label();
	self.AllegianceCaption:SetParent(self.SettingsTab);
	self.AllegianceCaption:SetPosition(0,self.EWCoordCaption:GetTop()+25);
	self.AllegianceCaption:SetSize(90,18);
	self.AllegianceCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.AllegianceCaption:SetForeColor(fontColor);
	self.AllegianceCaption:SetText("Ally:");
	self.AllegianceCaption:SetMouseVisible(false);

	self.AllegianceButtons=GaranStuff.MoorMap.RadioButtonGroup();
	self.AllegianceButtons:SetParent(self.SettingsTab);
	self.AllegianceButtons:SetSize(440,20);
	self.AllegianceButtons:SetPosition(90,self.AllegianceCaption:GetTop());
	self.AllegianceButtons.UnselectedIcon="GaranStuff/MoorMap/Resources/RB_unselected.tga";
	self.AllegianceButtons.SelectedIcon="GaranStuff/MoorMap/Resources/RB_selected.tga";
	self.AllegianceButtons.IconWidth=16;
	self.AllegianceButtons.IconHeight=16;
	self.AllegianceButtons:SetBorderColor(backColor);
	self.AllegianceButtons:SetBackColor(backColor);
	self.AllegianceButtons:SetTextColor(fontColor);
	self.AllegianceButtons:AddChoice("None");
	self.AllegianceButtons:AddChoice("Creep");
	self.AllegianceButtons:AddChoice("Freep");
	self.AllegianceButtons:AddChoice("Delving");
	self.AllegianceButtons:SetRows(1);
	self.AllegianceButtons:SetSelectedChoice(1);
	self.AllegianceButtons.SelectionChanged=function()
	end

	self.DataCaption=Turbine.UI.Label();
	self.DataCaption:SetParent(self.SettingsTab);
	self.DataCaption:SetPosition(0,self.AllegianceCaption:GetTop()+25);
	self.DataCaption:SetSize(90,18);
	self.DataCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.DataCaption:SetForeColor(fontColor);
	self.DataCaption:SetText("Data:");
	self.DataCaption:SetMouseVisible(false);
	self.DataText=Turbine.UI.Lotro.TextBox();
	self.DataText:SetParent(self.SettingsTab);
	self.DataText:SetPosition(90,self.DataCaption:GetTop());
	self.DataText:SetSize(250,18);
	self.DataText:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.DataText:SetMultiline(false);

	self.NPCTypeCaption=Turbine.UI.Label();
	self.NPCTypeCaption:SetParent(self.SettingsTab);
	self.NPCTypeCaption:SetPosition(0,self.DataCaption:GetTop()+25);
	self.NPCTypeCaption:SetSize(90,18);
	self.NPCTypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.NPCTypeCaption:SetForeColor(fontColor);
	self.NPCTypeCaption:SetText("NPC Type:");
	self.NPCTypeCaption:SetMouseVisible(false);

	self.NPCTypeButtons=GaranStuff.MoorMap.RadioButtonGroup();
	self.NPCTypeButtons:SetParent(self.SettingsTab);
	self.NPCTypeButtons:SetSize(440,60);
	self.NPCTypeButtons:SetPosition(90,self.NPCTypeCaption:GetTop());
	self.NPCTypeButtons.UnselectedIcon="GaranStuff/MoorMap/Resources/RB_unselected.tga";
	self.NPCTypeButtons.SelectedIcon="GaranStuff/MoorMap/Resources/RB_selected.tga";
	self.NPCTypeButtons.IconWidth=16;
	self.NPCTypeButtons.IconHeight=16;
	self.NPCTypeButtons:SetBorderColor(backColor);
	self.NPCTypeButtons:SetBackColor(backColor);
	self.NPCTypeButtons:SetTextColor(fontColor);
	self.NPCTypeButtons:AddChoice("None");
	self.NPCTypeButtons:AddChoice("Bard/Corrupter");
	self.NPCTypeButtons:AddChoice("Trainer");
	self.NPCTypeButtons:AddChoice("Barter");
	self.NPCTypeButtons:AddChoice("Merchant");
	self.NPCTypeButtons:AddChoice("Stablemaster");
	self.NPCTypeButtons:AddChoice("Captain General");
	self.NPCTypeButtons:AddChoice("Named Mob");
	self.NPCTypeButtons:SetRows(3);
	self.NPCTypeButtons:SetSelectedChoice(1);
	self.NPCTypeButtons.SelectionChanged=function()
	end

	self.QuestTypeCaption=Turbine.UI.Label();
	self.QuestTypeCaption:SetParent(self.SettingsTab);
	self.QuestTypeCaption:SetPosition(0,self.NPCTypeCaption:GetTop()+65);
	self.QuestTypeCaption:SetSize(90,18);
	self.QuestTypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.QuestTypeCaption:SetForeColor(fontColor);
	self.QuestTypeCaption:SetText("Quest Type:");
	self.QuestTypeCaption:SetMouseVisible(false);

	self.QuestTypeButtons=GaranStuff.MoorMap.RadioButtonGroup();
	self.QuestTypeButtons:SetParent(self.SettingsTab);
	self.QuestTypeButtons:SetSize(440,60);
	self.QuestTypeButtons:SetPosition(90,self.QuestTypeCaption:GetTop());
	self.QuestTypeButtons.UnselectedIcon="GaranStuff/MoorMap/Resources/RB_unselected.tga";
	self.QuestTypeButtons.SelectedIcon="GaranStuff/MoorMap/Resources/RB_selected.tga";
	self.QuestTypeButtons.IconWidth=16;
	self.QuestTypeButtons.IconHeight=16;
	self.QuestTypeButtons:SetBorderColor(backColor);
	self.QuestTypeButtons:SetBackColor(backColor);
	self.QuestTypeButtons:SetTextColor(fontColor);
	self.QuestTypeButtons:AddChoice("None");
	self.QuestTypeButtons:AddChoice("Creep");
	self.QuestTypeButtons:AddChoice("Creep Grams");
	self.QuestTypeButtons:AddChoice("Creep Lugz");
	self.QuestTypeButtons:AddChoice("Creep Isen");
	self.QuestTypeButtons:AddChoice("Creep TA");
	self.QuestTypeButtons:AddChoice("Creep TR");
	self.QuestTypeButtons:AddChoice("Creep LC");
	self.QuestTypeButtons:AddChoice("Freep");
	self.QuestTypeButtons:SetRows(3);
	self.QuestTypeButtons:SetSelectedChoice(1);
	self.QuestTypeButtons.SelectionChanged=function()
	end

	self.DropTypeCaption=Turbine.UI.Label();
	self.DropTypeCaption:SetParent(self.SettingsTab);
	self.DropTypeCaption:SetPosition(0,self.QuestTypeCaption:GetTop()+65);
	self.DropTypeCaption:SetSize(90,18);
	self.DropTypeCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	self.DropTypeCaption:SetForeColor(fontColor);
	self.DropTypeCaption:SetText("Drop Type:");
	self.DropTypeCaption:SetMouseVisible(false);

	self.DropTypeButtons=GaranStuff.MoorMap.RadioButtonGroup();
	self.DropTypeButtons:SetParent(self.SettingsTab);
	self.DropTypeButtons:SetSize(440,60);
	self.DropTypeButtons:SetPosition(90,self.DropTypeCaption:GetTop());
	self.DropTypeButtons.UnselectedIcon="GaranStuff/MoorMap/Resources/RB_unselected.tga";
	self.DropTypeButtons.SelectedIcon="GaranStuff/MoorMap/Resources/RB_selected.tga";
	self.DropTypeButtons.IconWidth=16;
	self.DropTypeButtons.IconHeight=16;
	self.DropTypeButtons:SetBorderColor(backColor);
	self.DropTypeButtons:SetBackColor(backColor);
	self.DropTypeButtons:SetTextColor(fontColor);
	self.DropTypeButtons:AddChoice("None");
	self.DropTypeButtons:AddChoice("Ruby Shard");
	self.DropTypeButtons:AddChoice("Saphire Shard");
	self.DropTypeButtons:AddChoice("Adamant Shard");
	self.DropTypeButtons:AddChoice("Beryl Shard");
	self.DropTypeButtons:AddChoice("Mithril Flake");
	self.DropTypeButtons:AddChoice("Symbol of Celebrimbor");
	self.DropTypeButtons:AddChoice("First Age thingy");
	self.DropTypeButtons:AddChoice("Spare");
	self.DropTypeButtons:SetRows(3);
	self.DropTypeButtons:SetSelectedChoice(1);
	self.DropTypeButtons.SelectionChanged=function()
	end

	-- quickslot to execute the command "/moormap target:;loc:;target"
	self.getTargetInfoContainer=Turbine.UI.Control();
	self.getTargetInfoContainer:SetParent(self.SettingsTab);
	self.getTargetInfoContainer:SetSize(32,32);
	self.getTargetInfoContainer:SetPosition(0,self.DropTypeCaption:GetTop()+25);
	self.getTargetInfo=Turbine.UI.Lotro.Quickslot();
	self.getTargetInfo:SetParent(self.getTargetInfoContainer);
	self.getTargetInfo:SetSize(66,66);
	self.getTargetInfo:SetPosition(-34,-34);
	self.getTargetInfo:SetAllowDrop(false);
	self.getTargetInfo:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, "/MoorMap target ;loc:;target"))
	self.getTargetInfo:SetVisible(true);
	self.getTargetInfoIcon=Turbine.UI.Control();
	self.getTargetInfoIcon:SetParent(self.getTargetInfoContainer);
	self.getTargetInfoIcon:SetPosition(0,0);
	self.getTargetInfoIcon:SetSize(32,32);
	self.getTargetInfoIcon:SetBackground(0x41000000);
	self.getTargetInfoIcon:SetBlendMode(Turbine.UI.BlendMode.Overlay);
	self.getTargetInfoIcon:SetMouseVisible(false);
	self.getTargetInfoIcon:SetVisible(true);

	self.getTargetInfo.MouseUp=function(sender,args)
		self.getTargetInfo:SetShortcut(Turbine.UI.Lotro.Shortcut( Turbine.UI.Lotro.ShortcutType.Alias, "/MoorMap target ;loc:;target"))
		self.getTargetInfo:SetVisible(true);
	end

	self.writeEntry=Turbine.UI.Lotro.Button();
	self.writeEntry:SetParent(self.SettingsTab);
	self.writeEntry:SetSize(32,32);
	self.writeEntry:SetPosition(40,self.DropTypeCaption:GetTop()+25);
	self.writeEntry:SetText("ADD");
	self.writeEntry.Click=function()
		local stringIndex=tonumber(self.StringIndexText:GetText());
		if stringIndex==nil or stringIndex==0 then
			stringIndex=1;
		end
		local NSCoord=tonumber(self.NSCoordText:GetText());
		local EWCoord=tonumber(self.EWCoordText:GetText());
		if NSCoord==nil then NSCoord=0 end
		if EWCoord==nil then EWCoord=0 end
		if self.NSButtons:GetSelectedChoice()==2 then NSCoord=0-NSCoord end
		if self.EWButtons:GetSelectedChoice()==2 then EWCoord=0-EWCoord end

		self.AnnotationText:SetText(self.AnnotationText:GetText()..string.char(9)..EncodeString("table.insert(tmpAnnotations,{"..tostring(self.MapSelect:GetValue())..","..tostring(NSCoord)..","..tostring(EWCoord)..", "..tostring(self.TypeList:GetValue())..", "..tostring(self.AllegianceButtons:GetSelectedChoice())..", "..tostring(stringIndex)..", \"\", "..self.DataText:GetText()..","..tostring(self.NPCTypeButtons:GetSelectedChoice()-1)..","..tostring(self.QuestTypeButtons:GetSelectedChoice()-1)..","..tostring(self.DropTypeButtons:GetSelectedChoice()-1).."});").."\r\n");
		self.ResourceText:SetText(self.ResourceText:GetText()..string.char(9)..EncodeString("tmpMapString[1]["..tostring(stringIndex).."]=\""..self.NameText:GetText()..": "..self.DescriptionText:GetText().."\";").."\r\n");

		self.StringIndexText:SetText(tostring(stringIndex+1));

	end
	self.AnnotationTab=Turbine.UI.Control();
	self.AnnotationTab:SetParent(self);
	self.AnnotationTab:SetPosition(10,40);
	self.AnnotationTab:SetSize(self:GetWidth()-20,self:GetHeight()-80);
	self.AnnotationTab:SetBackColor(Turbine.UI.Color(0,0,0));
	self.AnnotationTab:SetVisible(false);
	self.AnnotationText=Turbine.UI.Lotro.TextBox();
	self.AnnotationText:SetParent(self.AnnotationTab);
	self.AnnotationText:SetFont(Turbine.UI.Lotro.Font.Verdana10) -- or Arial12
	self.AnnotationText:SetMultiline(true);
	self.AnnotationText:SetPosition(0,0);
	self.AnnotationText:SetSize(self.AnnotationTab:GetWidth()-10,self.AnnotationTab:GetHeight());
	self.AnnotationText:SetText("");

	self.ResourceTab=Turbine.UI.Control();
	self.ResourceTab:SetParent(self);
	self.ResourceTab:SetPosition(10,40);
	self.ResourceTab:SetSize(self:GetWidth()-20,self:GetHeight()-80);
	self.ResourceTab:SetBackColor(Turbine.UI.Color(0,0,0));
	self.ResourceTab:SetVisible(false);
	self.ResourceText=Turbine.UI.Lotro.TextBox();
	self.ResourceText:SetParent(self.ResourceTab);
	self.ResourceText:SetFont(Turbine.UI.Lotro.Font.Verdana10) -- or Arial12
	self.ResourceText:SetMultiline(true);
	self.ResourceText:SetPosition(0,0);
	self.ResourceText:SetSize(self.ResourceTab:GetWidth()-10,self.ResourceTab:GetHeight());
	self.ResourceText:SetText("");

	self.Recover=Turbine.UI.Lotro.Button();
	self.Recover:SetParent(self.SettingsTab);
	self.Recover:SetPosition(15,self.getTargetInfoContainer:GetTop()+42);
	self.Recover:SetSize(100,20);
	self.Recover:SetText("Recover");
	self.Recover.Click=function()
		self.AnnotationText:SetText(convBack(self.AnnotationText:GetText()));
		self.ResourceText:SetText(convBack(self.ResourceText:GetText()));
	end

	self.ShowSettings=Turbine.UI.Lotro.Button();
	self.ShowSettings:SetParent(self);
	self.ShowSettings:SetPosition(25,self:GetHeight()-35);
	self.ShowSettings:SetSize(100,20);
	self.ShowSettings:SetText("Settings");
	self.ShowSettings.Click=function()
		self.SettingsTab:SetVisible(true);
		self.AnnotationTab:SetVisible(false);
		self.ResourceTab:SetVisible(false);
	end

	self.ShowAnnotations=Turbine.UI.Lotro.Button();
	self.ShowAnnotations:SetParent(self);
	self.ShowAnnotations:SetPosition((self:GetWidth()-80)/2,self:GetHeight()-35);
	self.ShowAnnotations:SetSize(100,20);
	self.ShowAnnotations:SetText("Annotations");
	self.ShowAnnotations.Click=function()
		self.SettingsTab:SetVisible(false);
		self.AnnotationTab:SetVisible(true);
		self.ResourceTab:SetVisible(false);
	end

	self.ShowResources=Turbine.UI.Lotro.Button();
	self.ShowResources:SetParent(self);
	self.ShowResources:SetPosition(self:GetWidth()-125,self:GetHeight()-35);
	self.ShowResources:SetSize(100,20);
	self.ShowResources:SetText("Resources");
	self.ShowResources.Click=function()
		self.SettingsTab:SetVisible(false);
		self.AnnotationTab:SetVisible(false);
		self.ResourceTab:SetVisible(true);
	end

	self.SetTargetInfo=function(Sender,NSCoord,EWCoord,iconType,tier,target)

		if not self.TypeLock.Locked and iconType~=nil and iconType~=0 then
			local tmpIndex;
			for tmpIndex=1,self.TypeList.ListData:GetItemCount() do
				if self.TypeList.ListData:GetItem(tmpIndex).DataValue==iconType then
					self.TypeList:SetSelectedIndex(tmpIndex);
					break;
				end
			end
		end
		if NSCoord<0 then
			self.NSCoordText:SetText(tostring(0-NSCoord));
			self.NSButtons:SetSelectedChoice(2);
		else
			self.NSCoordText:SetText(tostring(NSCoord));
			self.NSButtons:SetSelectedChoice(1);
		end
		if EWCoord<0 then
			self.EWCoordText:SetText(tostring(0-EWCoord));
			self.EWButtons:SetSelectedChoice(2);
		else
			self.EWCoordText:SetText(tostring(EWCoord));
			self.EWButtons:SetSelectedChoice(1);
		end
		if tier==nil or tier=="" then
			self.DataText:SetText("");
		else
			self.DataText:SetText(tostring(tier));
		end
		self.NameText:SetText(target);
		self.DescriptionText:SetText(target);
	end
	self:SetZOrder(self:GetZOrder()+1);
end


EncodeString=function(str)
	local ret = "";
	for i,v in ipairs({str:byte(1,-1)}) do
		if (v < 32) or (v > 125) then
			ret = ret .. "\\"..string.sub(string.format("00%d",v),-3);

		else
			ret = ret .. string.char(v);
		end
	end
	return ret;
end

LTrim=function(srcString)
	while string.sub(srcString,1,1)==" " do
		srcString=string.sub(srcString,2);
	end
	return srcString;
end
