-- Create a simple window for status. In the "Update" event handler, Read the defaults, Output the saved data files. unload the plugin 
-- we can't guarantee that the data is flushed to disk until we unload so we use another plugin, MoorMapTerminator to terminate
-- this plugin AFTER the data is processed and saved. The main app will detect MoorMapTerminator and will in turn terminate that.

-- the annotations should be moved to the MapData_x files so that all map specific data is in one place
-- but for now, it's kind of convenient for them to be here

import "GaranStuff.MoorMap.Class";
import "GaranStuff.MoorMap.VindarPatch";
import "GaranStuff.MoorMap.Strings";
import "GaranStuff.MoorMap.Table";

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";

language=1;

-- all annotations have the form:{MapID, N/S, E/W, IconID, Allegiance, TextID, Description, NPCRank/MapID/Tier, NPC Type, QuestType, SpecialLoot}
-- Annotation Type follows the Map Filter types plus the Creep specific "Map In"
-- TextID is only valid for the defaults and will allow using the appropriately translated text value from Resource
-- IconID:
-- 1=uncontestable home base (Grams, GV)
-- 2=fixed control, attackable base (Ost, DG)
-- 3=contestable base (LC, TR, TA, Isen, LC)
-- 4=contestable outpost (ROP,POP,SOP,AE,IsenOP)
-- 5=point of interest (STAB, WTAB, Grothum, HH, DC)
-- 6=minor fortification (EC,OC)
-- 7=Rez Circle
-- 8=Crude Map in
-- 9=Poor Map in
-- 10=Good Map in
-- 11=NPC
-- 12=Freep Map in
-- 14=Autioneer
-- 15=Barber
-- 16=Bard
-- 17=Camp Site 0x410d4636 (15x15), 0x410d4635 (30x30)/highlight 0x410d4637 (30x30)
-- 18=Crafting Facility
-- 19=Crafting Resource (not sure I want to include these...)
-- 20=Crafting Vendor
-- 21=Faction Representative
-- 22=Fellow (not available without Lua map info)
-- 23=Fellowship Leader (not available without Lua map info)
-- 24=Fellowship Shared Tracking (not available without Lua map info)
-- 25=Item-Master
-- 26=Mailbox 0x41007f7a (18x18)
-- 27=Milestone
-- 28=Pet (not available without Lua map info)
-- 29=Quest NPC/location/item
-- 30=Quest Escort (not available without Lua map info)
-- 31=Quest Failer (not available without Lua map info)
-- 32=Reflecting Pool
-- 33=Settlement
-- 34=Stable-master
-- 35=Town Crier
-- 36=Tracked Target (not available without Lua map info)
-- 37=Trader 0x410d465a (16x16) 0x410d465c (30x30)/highlight 0x410d465d
-- 38=Trainer
-- 39=Vault-keeper
-- 40=Vendor
-- 41=Map connector 0x410081a2 (63x63)
-- 42=Skirmish Camp
-- 43= Ore Node
-- 44= Wood Node
-- 45= Scholar Node
-- 46= Cook Ingredient
-- 47= Muster Horn
-- 48= Scholar Ingredient
-- 49=Interior/Instanced area
-- 50=Taskboard
-- 51=Stair Up (Interior connector)
-- 52=Stair Down (Interior connector)
-- 53=Quest Item

-- Allegiance:
-- 1=Contestable
-- 2=Creep
-- 3=Freep
-- 4=Delving

-- NPC Rank(for type=11)/MapID(for type=13)/Tier (for type=43,44,45):
-- 0=undefined/not an npc
-- 1=generic
-- 2=Tyrant
-- 3=Taskmaster
-- 4=Chieftain
-- 5=Soldier
-- 6=CG
-- 7=First Marshal
-- 8=Lietenant
-- 9=Sergeant-at-Arms

-- NPC Type
-- nil/0=generic (or not an NPC)
-- 1=Corrupter/Bard
-- 2=Trainer
-- 3=Barter
-- 4=Merchant
-- 5=Stablemaster
-- 6=Tyrant/Commander
-- 7=Named Quest Mob/Ally
-- 

-- Quest Type: (note, this is a bit mask so more than one may apply)
-- 0=not quest granter
-- 1=Creep generic
-- 2=Creep Grams Map Credit
-- 4=Creep Lugz Map Credit
-- 8=Creep Isen Map Credit
-- 16=Creep TA Map Credit
-- 32=Creep TR Map Credit
-- 64=Creep LC Map Credit
-- 128=Freep generic

-- Special Drops (note, this is a bit mask so more than one may apply) beryl ruby saphire adamant
-- 0=none
-- 1=Ruby Shard
-- 2=Saphire Shard
-- 4=Adamant Shard
-- 8=Beryl Shard
-- 16= Mithril Flake
-- 32= Symbol of Celebrimbor (not sure this is worth tracking since they drop mostly from instance chests now)
-- 64=.. whatever the lvl 65 first age crafting item will be
-- 128=..spare


-- mapInfo is in the form {Index,StringResourceID, ImageResourceID/Path, Width, Height, HFactor,HOffset,WFactor,WOffset,ParentMapID,MapType,Region,MaxNS,MinEW,MinNS,MaxEW,Tier,StringResourceID_DE,StringResourceID_FR,StringResourceID_RU,{northern boundary points},{western boundary points},{southern boundary points},{eastern boundary points}}
-- HFactor and HOffset are used in the conversion from map coordinates to pixels: X=Height*HFactor+HOffset will convert coordinate "Height" to pixel "X"
-- -- the excel spreadsheet "MoorMap Data.xls" contains the calculated values using two points, one at top left of map, the other at bottom right of map.
-- -- source columns: B=top left NS, C=top left world EW, D=top left pixel world X, E=top left pixel Y, F=bottom right NS, G=bottom right world EW, H=bottom right pixel world X, I=bottom right pixel Y
-- -- calculated columns: J=hFactor, M=hOffset, N=wFactor, Q=wOffset
-- ParentMapID is used to create the tree structure
-- MapTypeID - 0=Undefined, 1=Parchment (coordinates match world coordinates), 2=Interior/Underground (coordinates do NOT match world coordinates), 3=Interior/Underground subzone (hidden until parent is moused over in list and coordinates do not match world)
-- Region is the region code (from /loc) 0=Undefined/world map, 1=Eriador, 2=Rhovanion
-- Min&Max coordinates are the corners of the map
-- Tier is the zoom level of the map with "Middle Earth" being 1, "Eriador" and "Rhovanion" being 2, etc. this is used to determine the best map for adding annotations whose coordinates are included in more than one map
-- Borders are triplets representing horizontal or vertical line segments. The first value is the common coordinate, the second and third values are the starting and ending points for the line segment - so for a northern boundary, the first value is the north/south coordinate for a line starting at the east/west value of the second coordinate extending to the east/west value of the third coordinate
-- iconInfo is in the form {StringResourceID, Height, Width, Image ResourceID/Path, Highlighted Image ResourceID/Path}

worldNames={}
worldNames[1]="Arkenstone";
worldNames[2]="Brandywine";
worldNames[3]="Crickhollow";
worldNames[4]="Dwarrowdelf";
worldNames[5]="Elendilmir";
worldNames[6]="Firefoot";
worldNames[7]="Gladden";
worldNames[8]="Imladris";
worldNames[9]="Landroval";
worldNames[10]="Meneldor";
worldNames[11]="Nimrodel";
worldNames[12]="Riddermark";
worldNames[13]="Silverlode";
worldNames[14]="Vilya";
worldNames[15]="Windfola";
worldNames[16]="_DE_Anduin";
worldNames[17]="_DE_Gwaihir";
worldNames[18]="_DE_Maiar";
worldNames[19]="_DE_Morthond";
worldNames[20]="_DE_Vanyar";
worldNames[21]="_DE_RP_Belegaer";
worldNames[22]="_EN_Eldar";
worldNames[23]="_EN_Evernight";
worldNames[24]="_EN_Gilrain";
worldNames[25]="_EN_Snowbourn";
worldNames[26]="_EN_Withywindle";
worldNames[27]="_EN_RP_Laurelin";
worldNames[28]="_FR_Sirannon";
worldNames[29]="_FR_RP_Estel";


function LoadDefaults()
	local tmpIconInfo={};
	local tmpMapInfo={};
	tmpIconInfo[1]={106,36,36,"GaranStuff/MoorMap/Resources/MainBase.tga","GaranStuff/MoorMap/Resources/MainBase_hover.tga","GaranStuff/MoorMap/Resources/MainBase_icon.tga"};
	tmpIconInfo[2]={107,32,32,"GaranStuff/MoorMap/Resources/Base.tga","GaranStuff/MoorMap/Resources/Base_hover.tga","GaranStuff/MoorMap/Resources/Base_icon.tga"};
	tmpIconInfo[3]={108,24,24,"GaranStuff/MoorMap/Resources/Fort.tga","GaranStuff/MoorMap/Resources/Fort_hover.tga","GaranStuff/MoorMap/Resources/Fort_icon.tga"};
	tmpIconInfo[4]={109,24,24,"GaranStuff/MoorMap/Resources/Outpost.tga","GaranStuff/MoorMap/Resources/Outpost_hover.tga","GaranStuff/MoorMap/Resources/Outpost_icon.tga"};
	tmpIconInfo[5]={110,30,30,0x41005e5e,0x41005e60,0x41005e5f};
	tmpIconInfo[6]={111,18,18,"GaranStuff/MoorMap/Resources/Stockade.tga","GaranStuff/MoorMap/Resources/Stockade_hover.tga","GaranStuff/MoorMap/Resources/Stockade_icon.tga"};
	tmpIconInfo[7]={112,24,24,"GaranStuff/MoorMap/Resources/Rez.tga","GaranStuff/MoorMap/Resources/Rez_hover.tga","GaranStuff/MoorMap/Resources/Rez_icon.tga"};
	tmpIconInfo[8]={113,18,18,"GaranStuff/MoorMap/Resources/CrudeMap.tga","GaranStuff/MoorMap/Resources/CrudeMap_hover.tga","GaranStuff/MoorMap/Resources/CrudeMap.tga"};
	tmpIconInfo[9]={114,18,18,"GaranStuff/MoorMap/Resources/PoorMap.tga","GaranStuff/MoorMap/Resources/PoorMap_hover.tga","GaranStuff/MoorMap/Resources/PoorMap.tga"};
	tmpIconInfo[10]={115,18,18,"GaranStuff/MoorMap/Resources/GoodMap.tga","GaranStuff/MoorMap/Resources/GoodMap_hover.tga","GaranStuff/MoorMap/Resources/GoodMap.tga"};
	tmpIconInfo[11]={116,16,16,"GaranStuff/MoorMap/Resources/NPC.tga","GaranStuff/MoorMap/Resources/NPC_hover.tga","GaranStuff/MoorMap/Resources/NPC.tga"};
	tmpIconInfo[12]={117,18,18,"GaranStuff/MoorMap/Resources/FreepMap.tga","GaranStuff/MoorMap/Resources/FreepMap_hover.tga","GaranStuff/MoorMap/Resources/FreepMap.tga"};
	tmpIconInfo[13]={118,18,18,"GaranStuff/MoorMap/Resources/UnearnedMap.tga","GaranStuff/MoorMap/Resources/UnearnedMap_hover.tga","GaranStuff/MoorMap/Resources/UnearnedMap.tga"};
	tmpIconInfo[14]={120,30,30,0x41005e9f,0x41005ea1,0x41005ea0}; -- auctioneer
	tmpIconInfo[15]={121,32,32,"GaranStuff/MoorMap/Resources/Barber.tga","GaranStuff/MoorMap/Resources/Barber_hover.tga","GaranStuff/MoorMap/Resources/Barber_icon.tga"};
	tmpIconInfo[16]={122,30,30,0x41005e6a,0x41005e6c,0x41005e6b}; -- bard

	tmpIconInfo[17]={123,30,30,0x410d4635,0x410d4637,0x410d4636}; -- Camp Site (mini=0x410d4636 (15x15))
	tmpIconInfo[18]={124,30,30,0x41005e76,0x41005e78,0x41005e77}; -- Craft Facility

	tmpIconInfo[19]={125,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- ResourceNode
	tmpIconInfo[20]={126,32,32,"GaranStuff/MoorMap/Resources/CraftVendor.tga","GaranStuff/MoorMap/Resources/CraftVendor_hover.tga","GaranStuff/MoorMap/Resources/CraftVendor_icon.tga"};
	tmpIconInfo[21]={127,32,32,"GaranStuff/MoorMap/Resources/FactionRep.tga","GaranStuff/MoorMap/Resources/FactionRep_hover.tga","GaranStuff/MoorMap/Resources/FactionRep_icon.tga"};
	tmpIconInfo[22]={128,30,30,0x41005e88,0x41005e8a,0x41005e89}; -- Fellow
	tmpIconInfo[23]={129,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- FellowLeader
	tmpIconInfo[24]={130,30,30,0x41005e98,0x41005e9a,0x41005e99}; -- FellowTrack
	tmpIconInfo[25]={131,32,32,"GaranStuff/MoorMap/Resources/Item-master.tga","GaranStuff/MoorMap/Resources/Item-master_hover.tga","GaranStuff/MoorMap/Resources/Item-master_icon.tga"};
	tmpIconInfo[26]={132,30,30,0x41005e94,0x41005e96,0x41005e95};--Mailbox 
	tmpIconInfo[27]={133,30,30,0x41005e52,0x41005e54,0x41005e53}; -- milestone
	tmpIconInfo[28]={134,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Pet
	tmpIconInfo[29]={135,30,30,0x41005e4e,0x41005e50,0x41005e4f}; -- Quest NPC
	tmpIconInfo[30]={136,0,0,"GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga","GaranStuff/MoorMap/Resources/placeholder.tga"}; -- Quest Escort
	tmpIconInfo[31]={137,30,30,0x41005e84,0x41005e86,0x41005e85}; -- Quest Failer
	tmpIconInfo[32]={138,30,30,0x41005ea3,0x41005ea5,0x41005ea4}; -- reflecting pool
	tmpIconInfo[33]={139,30,30,0x41005e56,0x41005e58,0x41005e57}; -- Settlement
	tmpIconInfo[34]={140,30,30,0x41005e72,0x41005e74,0x41005e73}; -- stablemaster

	tmpIconInfo[35]={141,32,32,"GaranStuff/MoorMap/Resources/TownCrier.tga","GaranStuff/MoorMap/Resources/TownCrier_hover.tga","GaranStuff/MoorMap/Resources/TownCrier_icon.tga"};
	tmpIconInfo[36]={142,30,30,0x41005e7f,0x41005e81,0x41005e80}; -- Tracked Target
	tmpIconInfo[37]={143,30,30,0x410d465c,0x410d465d,0x410d465a}; -- Trader mini=0x410d465a (16x16)
	tmpIconInfo[38]={144,30,30,0x41005e66,0x41005e68,0x41005e67}; -- Trainer
	tmpIconInfo[39]={145,30,30,0x41005e9d,0x41005e9d,0x41005e9e}; -- vaultkeeper doesn't have a highlighted icon with the other icons :(

	tmpIconInfo[40]={146,30,30,0x41005e6e,0x41005e70,0x41005e6f}; -- vendor
	tmpIconInfo[41]={147,63,63,"GaranStuff/MoorMap/Resources/MapConnector_blank.tga",0x410081a2,0x410081a2};
	tmpIconInfo[42]={154,32,32,"GaranStuff/MoorMap/Resources/SkirmishCamp.tga","GaranStuff/MoorMap/Resources/SkirmishCamp_hover.tga","GaranStuff/MoorMap/Resources/SkirmishCamp_icon.tga"};
	tmpIconInfo[43]={155,24,24,"GaranStuff/MoorMap/Resources/OreNode.tga","GaranStuff/MoorMap/Resources/OreNode_hover.tga","GaranStuff/MoorMap/Resources/OreNode_icon.tga"};
	tmpIconInfo[44]={156,24,24,"GaranStuff/MoorMap/Resources/WoodNode.tga","GaranStuff/MoorMap/Resources/WoodNode_hover.tga","GaranStuff/MoorMap/Resources/WoodNode_icon.tga"};
	tmpIconInfo[45]={157,24,24,"GaranStuff/MoorMap/Resources/ScholarNode.tga","GaranStuff/MoorMap/Resources/ScholarNode_hover.tga","GaranStuff/MoorMap/Resources/ScholarNode_icon.tga"};
	tmpIconInfo[46]={162,24,24,"GaranStuff/MoorMap/Resources/Cook.tga","GaranStuff/MoorMap/Resources/Cook_hover.tga","GaranStuff/MoorMap/Resources/Cook_icon.tga"};
	tmpIconInfo[47]={163,32,32,"GaranStuff/MoorMap/Resources/MusterHorn.tga","GaranStuff/MoorMap/Resources/MusterHorn_hover.tga","GaranStuff/MoorMap/Resources/MusterHorn_icon.tga"};
	tmpIconInfo[48]={182,24,24,"GaranStuff/MoorMap/Resources/Scholar.tga","GaranStuff/MoorMap/Resources/Scholar_hover.tga","GaranStuff/MoorMap/Resources/Scholar_icon.tga"};
	tmpIconInfo[49]={183,32,32,"GaranStuff/MoorMap/Resources/Dungeon.tga","GaranStuff/MoorMap/Resources/Dungeon_hover.tga","GaranStuff/MoorMap/Resources/Dungeon_icon.tga"};
	tmpIconInfo[50]={218,32,32,"GaranStuff/MoorMap/Resources/Taskboard.tga","GaranStuff/MoorMap/Resources/Taskboard_hover.tga","GaranStuff/MoorMap/Resources/Taskboard_icon.tga"};
	tmpIconInfo[51]={248,32,32,"GaranStuff/MoorMap/Resources/StairUp.tga","GaranStuff/MoorMap/Resources/StairUp_hover.tga","GaranStuff/MoorMap/Resources/Stair_icon.tga"};
	tmpIconInfo[52]={249,32,32,"GaranStuff/MoorMap/Resources/StairDn.tga","GaranStuff/MoorMap/Resources/StairDn_hover.tga","GaranStuff/MoorMap/Resources/Stair_icon.tga"};
	tmpIconInfo[53]={272,30,30,0x41005e4e,0x41005e50,0x41005e4f};

	-- Map Data
	tmpMapInfo[1]={1,19,0x41008133,1024,768,63.6,1541,-63.5,-630,3,1,1,-10,-24.3,-22,-8.2,3}; -- ettenmoors
	tmpMapInfo[2]={2,20,0x41008139,1024,768, 1, 0, 1, 0,0,1,0,0,0,0,0,1}; -- Middle Earth coordinates are meaningless on this map :( different systems are in use in Eriador and Rhovanion
	tmpMapInfo[3]={3,21,0x41008138,1024,768,6.5,951,-6.5,186,2,1,1,28.6,-146.4,-89.4,11.1,2,0x4101E0AE,0x4101E0A8,0x410EE3C8}; -- Eriador
	tmpMapInfo[4]={4,22,0x41008131,1024,768,35.03,1498,-34.95,514,3,1,1,14.7,-42.8,-7.3,-13.6,3}; -- Angmar
	tmpMapInfo[5]={5,23,0x41008136,1024,768,36.27,2377,-36.18,-640,3,1,1,-17.7,-65.6,-38.9,-37.4,3}; -- Bree-land
	tmpMapInfo[6]={6,24,0x41008135,1024,768,182.68,9280,-182.62,-4414,5,1,1,-24.2,-50.8,-28.4,-45.2,4,0x4101E0A1,0x4101e0ba}; -- Archet 
	tmpMapInfo[7]={7,25,0x4110a841,1024,768,213.13,12203,-213.06,-6370,5,1,1,-29.9,-57.3,-33.5,-52.5,4}; -- Barrow Downs North
	tmpMapInfo[8]={8,26,0x4110a842,1024,768,173.38,10012,-174.32,-5700,5,1,1,-32.7,-57.8,-37.1,-51.9,4}; -- Barrow Downs South
	tmpMapInfo[9]={9,27,0x41008134,1024,768,150,8194,-150,-4210,5,1,1,-28.1,-54.6,-33.2,-47.8,4}; -- Bree
	tmpMapInfo[10]={10,28,0x410d9a54,1024,768,189.44,9468,-191.75,-6519,5,1,1,-34,-50,-38,-44.6,4}; -- Bree-land Homesteads
	tmpMapInfo[11]={11,29,0x410e4ddd,1024,768,79.90,5206,-79.90,-2332,5,1,1,-29.2,-65.2,-38.8,-52.4,4}; -- The Old Forest
	tmpMapInfo[12]={12,30,0x411041a4,1024,768,32.99,1041,-32.92,-1767,3,1,1,-53.7,-31.6,-77,-.6,3,nil,nil,0x411041ac}; -- Enedwaith
	tmpMapInfo[13]={13,31,0x4100812c,1024,768,38.7,4371,-38.66,-484,3,1,1,-12.6,-113,-32.4,-86.6,3}; -- Ered Luin
	tmpMapInfo[14]={14,32,0x410d9934,1024,768,182.78,17099,-182.72,-4437,13,1,1,-24.3,-93.6,-28.5,-88,4}; -- Falathlorn Homesteads
	tmpMapInfo[15]={15,33,0x4100812b,1024,768,128.70,13735,-128.75,-1442,13,1,1,-11.2,-106.8,-17.2,-98.8,4}; -- Thorin's Gate
	tmpMapInfo[16]={16,34,0x410d9a56,1024,768,192.45,21143,-192.65,-2531,13,1,1,-13.2,-109.9,-17.2,-104.6,4}; -- Thorin's Hall Homesteads
	tmpMapInfo[17]={17,35,0x410e8686,1024,768,33.8,802,-33.75,-1188,3,1,1,-35.2,-23.8,-58,6.5,3,nil,0x410f5e2f,0x411012D8}; -- Eregion
	tmpMapInfo[18]={18,36,0x410e8694,1024,768,138.8,1237,-139.5,-6765,17,1,1,-48.5,-9,-54,-1.6,4}; -- The Walls of Moria
	tmpMapInfo[19]={19,37,0x4101f084,1024,768,33.7,2783,-33.71,-53,3,1,1,-1.6,-82.6,-24.4,-52.3,3}; -- Evendim
	tmpMapInfo[20]={20,38,0x410E6EAD,1024,768,134.61,9890,-134.56,-2085,19,1,1,-15.5,-73.5,-21.2,-65.9,4}; -- Annuminas
	tmpMapInfo[21]={21,39,0x410e3f46,1024,768,25.02,2320,-25.07,625,3,1,1,24.9,-92.8,-5.7,-51.9,3}; -- Forochel
	tmpMapInfo[22]={22,40,0x4110d5a5,1024,768,213.13,20545,-213.06,3069,3,1,1,14.4,-96.4,10.8,-91.6,3}; -- Frostbluff
	tmpMapInfo[23]={23,41,0x41008130,1024,768,43.72,1935,-43.83,-1148,3,1,1,-26.2,-44.3,-43.7,-20.9,3}; -- Lone-lands
	tmpMapInfo[24]={24,42,0x4100812f,1024,768,41.30,489,-41.24,-602,3,1,1,-14.6,-11.9,-33.2,12.9,3}; -- Misty Mountains
	tmpMapInfo[25]={25,43,0x41008132,1024,768,36.28,2190,-36.18,-47,3,1,1,-1.3,-60.4,-22.5,-32.2,3}; -- North Downs
	tmpMapInfo[26]={26,44,0x41008137,1024,768,48.48,3921,-48.24,-1104,3,1,1,-22.9,-80.9,-38.8,-59.8,3}; -- The Shire
	tmpMapInfo[27]={27,45,0x410d9a57,1024,768,182.68,14130,-178.37,-6171,26,1,1,-34.6,-77.4,-38.9,-71.8,4}; -- Shire Homesteads
	tmpMapInfo[28]={28,46,0x4100812e,1024,768,37.61,988,-37.41,-778,3,1,1,-20.8,-26.3,-41.3,.9,3}; -- Trollshaws
	tmpMapInfo[29]={29,47,0x4100812d,1024,768,105.46,982,-106.53,-2801,28,1,1,-26.3,-9.4,-33.5,.3,4,nil,nil,nil,{{-26.0,-7.2,1.2}},{{-7.2,-26.0,-33.2}},{{-31.6,-7.2,-3},{-33.2,-3,1.2}},{{1.2,-26,-33.2}}}; -- Rivendell
	tmpMapInfo[30]={30,48,0x410e868b,1024,768,5.98,876,-5.93,252,2,1,2,42.4,-146.5,-86.9,24.6,2,nil,nil,0x410f5e5a}; -- Rhovanion
	tmpMapInfo[31]={31,49,0x410e8707,1024,768,48.7,3995,-48.63,-223,30,1,2,-4.6,-82,-20.4,-61,3}; -- Lothlrien
	tmpMapInfo[32]={32,50,0x410e8706,1024,768,179.47,12568,-178.37,-2300,31,1,2,-12.9,-70,-17.2,-64.3,4}; -- Caras Galadhon
	tmpMapInfo[33]={33,51,0x41100DF2,1024,768,41.2,2618,-41.2,-200,30,1,2,-4.9,-63.6,-23.5,-38.8,3}; -- mirkwood
-- moria
	tmpMapInfo[34]={34,52,0x410e8708,1024,768,30,3653,-29.9,86,30,1,2,2.8,-121.8,-22.8,-87.7,3}; -- moria
	tmpMapInfo[35]={35,53,0x410e871d,1024,768,63.94,7289,-63.92,128,34,1,2,2,-114,-10,-98,4}; -- Durin's Way
	tmpMapInfo[36]={36,54,0x410e8716,1024,768,136.4,15286,-136.96,-1698,34,1,2,-12.4,-112.1,-18,-104.6,4}; -- Flaming Deeps
	tmpMapInfo[37]={37,55,0x410e8715,1024,768,132.86,13658,-132.24,-1401,34,1,2,-10.6,-102.8,-16.4,-95.1,4}; -- Foundations of Stone
	tmpMapInfo[38]={38,56,0x410e871a,1024,768,91.4,9612,-91.4,-365,34,1,2,-4,-105.2,-12.4,-94,4}; -- Nud Melek
	tmpMapInfo[39]={39,57,0x410e8718,1024,768,106.56,11632,-108.03,-1004,34,1,2,-9.3,-109.2,-16.4,-99.6,4}; -- Redhorn Lodes
	tmpMapInfo[40]={40,58,0x410e8e5a,1024,768,162.38,22967,-163.19,12060,34,1,2,73.9,-141.5,69.2,-135.2,4}; -- The Grand Stair
	tmpMapInfo[41]={41,59,0x410e871c,1024,768,141.8,16620,-141.8,-698,34,1,2,-4.9,-117.2,-10.3,-110,4}; -- The Great Delving
	tmpMapInfo[42]={42,60,0x410e8719,1024,768,142.08,16486,-142.04,-1221,34,1,2,-8.6,-116.1,-14,-108.9,4}; -- The Silvertine Lodes
	tmpMapInfo[43]={43,61,0x410e8717,1024,768,74.0566,8921,-73.9583,-835,34,1,2,-12.36,-117.56,-19,-109.07,4}; -- The Waterworks
	tmpMapInfo[44]={44,62,0x410e871b,1024,768,76.34,8700,-75.94,-296,34,1,2,-3.9,-114,-14,-100.6,4}; -- Zelem Melek
	tmpMapInfo[45]={45,63,0x410e871e,1024,768,134.61,15209,-134.56,2328,34,1,2,17.3,-113,11.6,-105.4,4}; -- Zirak Zigil
-- these are the first "interior" maps
	tmpMapInfo[46]={46,184,0x41005d2f,1600,1200,300,-13450,-300,23550,15,2,1,77.8,46.42,75.31,48.75,5}; -- Thorin's Hall main floor
	tmpMapInfo[47]={47,185,0x410d4163,1600,1200,300,-13450,-300,23550,15,2,1,77.1,47.08,76.59,48.06,5}; -- Thorin's Hall basement
	tmpMapInfo[48]={48,186,0x410d81c3,1600,1200,300,-15185,-300,-19395,1,2,1,-65.44,52.0,-67.85,54.53,4}; -- Delving of Fror

	tmpMapInfo[49]={49,187,0x41005c2f,800,600,1,0,1,0,5,3,1,0,0,0,0,4}; -- Breeland Brigand Cave
	tmpMapInfo[50]={50,188,0x41007dc5,800,600,1,0,1,0,15,3,1,0,0,0,0,5}; -- Rockbelly Pit
	tmpMapInfo[51]={51,189,0x41007dbe,800,600,300,-15552,-300,-1445,6,3,1,-5.46,52.54,-6.18,53.78,5}; -- Sprigley's Cellar actual
	tmpMapInfo[52]={52,190,0x41005C0D,800,600,1,0,1,0,15,3,1,0,0,0,0,5}; -- Mirkstone Tunnels
	tmpMapInfo[53]={53,191,0x41005C1F,800,600,1,0,1,0,15,3,1,0,0,0,0,5}; -- Silver Deep
	tmpMapInfo[54]={54,192,0x41005C2D,1600,1200,1,0,1,0,15,3,1,0,0,0,0,5}; -- Skorgrim's Tomb
	tmpMapInfo[55]={55,193,0x41110D27,800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Valandur
	tmpMapInfo[56]={56,194,0x41110D29,800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Erendur
	tmpMapInfo[57]={57,195,0x41110D2C,1600,1200,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Eldacar
	tmpMapInfo[58]={58,196,0x41110D2E,1600,1200,1,0,1,0,19,3,1,0,0,0,0,4}; -- Annuminas: Haudh Arantar
	tmpMapInfo[59]={59,197,0x4101fd4f,800,600,1,0,1,0,19,3,1,0,0,0,0,4}; -- Evendim: Gwindethrond
-- new RoI maps
	tmpMapInfo[60]={60,203,0x41119615,1024,768,31.2844,892,-31.3061,-2207,3,1,1,-70.5,-28.5,-95,4.2,3,nil,nil,0x41119612}; -- Dunlending
	tmpMapInfo[61]={61,204,0x4111961d,1024,768,38.31461,1096,-38.1592,-2701,60,1,1,-70.8,-28.1,-90.9,-1.9,4,nil,nil,0x41119622}; -- Dunland
	tmpMapInfo[62]={62,205,0x41116d55,1024,768,51.40704,1070,-51.4765,-4138,60,1,1,-80.4,-20.8,-94.4,-2.0,4,0x41116edc,0x41116edd,0x41116ee0}; -- Gap Of Rohan
	tmpMapInfo[63]={63,206,0x41119607,1024,768,75.22059,715,-74.466,-5666,60,1,1,-76.1,-9.5,-86.0,3.8,4,nil,nil,0x4111960c}; -- Nan Curunir
	tmpMapInfo[64]={64,207,0x41116EFE,1024,768,284.1667,5229,-284.074,-22413,61,1,1,-78.9,-18.4,-81.8,-14.8,5,nil,nil,0x41116f03}; -- Galtrev
	tmpMapInfo[65]={65,208,0x41116f01,1024,768,132.8571,838,-132.241,-10090,63,1,1,-76.3,-6.3,-82.1,1.4,5,nil,nil,0x41116f0c}; -- Isengard
-- Isengard Depths 0x4111923d
-- Ring of Isengard 0x41119257
	tmpMapInfo[66]={66,209,0x411195ff,1024,768,258.8745,24421.9,-256.585,13425.52,62,1,1,52.1,-93.7,49.6,-91.0,5}; -- Pit of Iron

-- the great river maps
	tmpMapInfo[67]={67,214,0x4111e1c0,1024,768,37.61029,2780,-37.598,-646,30,1,2,-17.2,-73.9,-37.6,-46.7,3,0x4111e1c1,0x4111e1c2}; -- the great river
	tmpMapInfo[68]={68,215,0x41123f09,1024,768,352.7586,22965,-348.636,-8681,67,1,2,-24.9,-65.1,-27.1,-62.2,4}; -- stangard
-- Tal Methedras
	tmpMapInfo[69]={69,216,0x4111b941,1024,768,113.289,1635.8,-112.794,-8132,60,1,1,-72.7,-12.3,-77.7,-7.1,4}; -- Tal Methedras after
	tmpMapInfo[70]={70,217,0x4111b941,1024,768,113.289,1635.8,-112.794,-8132,60,1,1,-72.7,-12.3,-77.7,-7.1,4}; -- Tal Methedras before

	tmpMapInfo[71]={71,228,0x41129eb7,1024,768,23.9019,1853.4,-23.8941,-799.452,30,1,2,-33.5,-77.5,-65.6,-34.7,3,0x41129eb3,0x41129eb1}; -- east rohan
	tmpMapInfo[72]={72,229,0x4112d1dd,1024,768,76.9173,6108.2,-77.4747,-2664.13,71,1,2,-34.4,-79.4,-44.3,-66.1,4,0x4112fcd6,0x4112fcd7}; -- eaves of fangorn
	tmpMapInfo[73]={73,230,0x4112d1dc,1024,768,42.9832,2635.9,-43.0899,-1968.21,71,1,2,-45.7,-61.3,-63.5,-37.5,4,0x4112fccd,0x4112fccf}; -- east wall
	tmpMapInfo[74]={74,231,0x4112d1e1,1024,768,49.1827,3655.3,-48.8535,-1899.3,71,1,2,-38.9,-74.3,-54.6,-53.5,4,0x4112fcdb,0x4112fcdc}; -- entwash vale
	tmpMapInfo[75]={75,232,0x4112d1e0,1024,768,47.1429,3159,-47.3457,-1982.78,71,1,2,-41.8,-67.0,-58.1,-45.3,4,0x4112fcdf,0x4112fce1}; -- Norcrofts
	tmpMapInfo[76]={76,233,0x4112d1df,1024,768,51.6667,3612.5,-51.8243,-2714.59,71,1,2,-52.4,-69.9,-67.2,-50.1,4,0x4112fce5,0x4112fce6}; -- sutcrofts
	tmpMapInfo[77]={77,234,0x4112d1de,1024,768,41.25,2649.3,-41.016,-1233.58,71,1,2,-30.1,-64.2,-48.8,-39.4,4,0x4112fceb,0x4112fcec}; -- The Wold

-- RoR cities
	tmpMapInfo[78]={78,235,0x41132e10,1024,768,249.1525,13594,-250.185,-9457,77,1,2,-37.9,-54.6,-40.9,-50.5,5,0x41132e11,0x41132e0f}; -- Harwick
	tmpMapInfo[79]={79,236,0x41132e57,1024,768,249.1409,15938,-249.791,-14803,76,1,2,-59.3,-64.0,-62.4,-59.9,5,0x41132e59,0x41132e5b}; -- Snowbourn

	tmpMapInfo[80]={80,237,"GaranStuff/MoorMap/Maps/Cliving.jpg",1024,768,249.6104,14575,-250.181,-10517.6,75,1,2,-42.1,-58.4,-45.2,-54.3,5}; -- Cliving
	tmpMapInfo[81]={81,244,"GaranStuff/MoorMap/Maps/Eaworth.jpg",512,384,248.7179,16132,-250.877,-11765.35,74,1,2,-46.9,-64.9,-48.5,-62.9,5}; -- Eaworth
-- more interiors
	tmpMapInfo[82]={82,242,"GaranStuff/MoorMap/Maps/Byrgenstow1.jpg",1024,768,300,-15738,-300,6742,74,3,2,21.62,53.46,20.68,54.86,5}; -- Byrgenstow
	tmpMapInfo[83]={83,243,"GaranStuff/MoorMap/Maps/Byrgenstow2.jpg",1024,768,300,-15738,-300,6742,74,3,2,21.62,53.46,20.68,54.86,5}; -- Byrgenstow
	tmpMapInfo[84]={84,245,"GaranStuff/MoorMap/Maps/Langraf.jpg",1024,768,400,58272,-397.5,-7391,76,3,2,-18.6,-145.7,-20.6,-143.2,5}; -- Langraf
	tmpMapInfo[85]={85,246,"GaranStuff/MoorMap/Maps/OstMagol1.jpg",1024,768,302.7397,-15975,-298.529,17696,75,3,2,59.2,52.7,56.7,56.1,5}; -- Ost Magol lower
	tmpMapInfo[86]={86,247,"GaranStuff/MoorMap/Maps/OstMagol2.jpg",1024,768,302.7397,-15975,-298.529,17696,75,3,2,59.2,52.7,56.7,56.1,5}; -- Ost Magol Upper
	tmpMapInfo[87]={87,250,"GaranStuff/MoorMap/Maps/TheLivingDeep.jpg",1024,768,297.2973,-14854,-300,16301,74,3,2,53.9,50.7,52.3,52.3,5}; -- The Living Deep
	tmpMapInfo[88]={88,251,"GaranStuff/MoorMap/Maps/Gerngarth1.jpg",1024,768,598,-31484,-598.413,35949,77,3,2,59.9,53,58.9,53.9,5}; -- Gerngarth lower
	tmpMapInfo[89]={89,252,"GaranStuff/MoorMap/Maps/Gerngarth2.jpg",1024,768,598,-31484,-598.413,35949,77,3,2,59.9,53,58.9,53.9,5}; -- Gerngarth upper
	tmpMapInfo[90]={90,253,"GaranStuff/MoorMap/Maps/Isengraf.jpg",1024,768,297.1831,-15195,-300,18746,76,3,2,62,51.9,60.3,53.6,5}; -- Isengraf
	tmpMapInfo[91]={91,254,"GaranStuff/MoorMap/Maps/Wyrmdelf1.jpg",1024,768,600,-32550,-590.909,14040,74,3,2,23.4,54.46,22.81,55.39,5}; -- Wyrmdelf lower (double size)
	tmpMapInfo[92]={92,255,"GaranStuff/MoorMap/Maps/Wyrmdelf2.jpg",1024,768,600,-32550,-590.909,14278,74,3,2,24.16,54.51,23.17,55.76,5}; -- Wyrmdelf upper (double size)
	tmpMapInfo[93]={93,256,"GaranStuff/MoorMap/Maps/Dwergfant.jpg",1024,768,297.7528,-15824,-297.872,18643,75,3,2,61.82,54.34,60.79,55.38,5}; -- Dwergfant
	tmpMapInfo[94]={94,257,"GaranStuff/MoorMap/Maps/TheAncientTomb.jpg",1024,768,300.8264,-14320,-300,8995,75,3,2,29.84,48.46,27.6,50.08,5}; -- The Ancient Tomb
	tmpMapInfo[95]={95,258,"GaranStuff/MoorMap/Maps/DigelonLower.jpg",1024,768,300,-15360,-304.688,18268,77,3,2,59.21,52.53,58.14,53.3,5}; -- Digelon Lower
	tmpMapInfo[96]={96,259,"GaranStuff/MoorMap/Maps/DigelonMiddle.jpg",1024,768,298.6301,-15333,-303.266,18061,77,3,2,58.91,52.5,57.74,53.59,5}; -- Digelon Middle
	tmpMapInfo[97]={97,260,"GaranStuff/MoorMap/Maps/DigelonUpper.jpg",1024,768,610.526,-31878,-610.526,35945,77,3,2,58.55,52.78,57.92,53.33,5}; -- Digelon Upper
	tmpMapInfo[98]={98,261,"GaranStuff/MoorMap/Maps/TheCreepingWood.jpg",1024,768,152.0833,22509,-149.02,-2211,76,3,2,-16.51,-146.04,-18.9,-143.49,5}; -- The Creeping Wood
-- goblin-town
	tmpMapInfo[99]={99,262,"GaranStuff/MoorMap/Maps/GoblinTownTunnelsSouth.jpg",1024,768,150.5747,-7804,-150.549,-10055,24,3,1,-67.58,53.46,-70.87,56.87,4}; -- Goblintown tunnels south 0x410d9810
	tmpMapInfo[100]={100,263,"GaranStuff/MoorMap/Maps/GoblinTownTunnelsCentral.jpg",1024,768,150.5495,-7817,-148.966,-9698,24,3,1,-66.5,54.11,-68.85,56.54,4}; -- Goblintown tunnels central 0x410d9812
	tmpMapInfo[101]={101,264,"GaranStuff/MoorMap/Maps/GoblinTownTunnelsNorth.jpg",1024,768,149.4186,-7845,-150.617,-9593,24,3,1,-64.7,54.93,-67.65,57.03,4}; -- Goblintown tunnels north 0x410d9811
	tmpMapInfo[102]={102,265,"GaranStuff/MoorMap/Maps/GoblinTownSlavePens.jpg",1024,768,297.2222,-15786,-303.509,-19323,24,3,1,-64.56,54.47,-65.31,55.19,4}; -- Goblintown Slave Pens 0x410d9813 (800x600)
	tmpMapInfo[103]={103,266,"GaranStuff/MoorMap/Maps/GoblinTownWarSteadings.jpg",1024,768,301.2821,-15903,-303.125,-19045,24,3,1,-63.47,53.87,-64.66,54.98,4}; -- Goblintown War Steadings 0x410d980d (800x600)
	tmpMapInfo[104]={104,267,"GaranStuff/MoorMap/Maps/GoblinTownThundergrot.jpg",1024,768,296.2264,-15766,-302.5,-19731,24,3,1,-65.81,54.4,-67.16,55.46,4}; -- Goblintown Thundergrot 0x410d980f ?
	tmpMapInfo[105]={105,268,"GaranStuff/MoorMap/Maps/GoblinTownGollumsCave.jpg",1024,768,298.2759,-16016,-297.143,-18500,24,3,1,-63.22,54.63,-63.97,56.17,4}; -- Gollums Cave 0x410d9814 (800x600)
	tmpMapInfo[106]={106,269,"GaranStuff/MoorMap/Maps/GreatGoblinsDen.jpg",1024,768,298.7952,-15724,-301.961,-18630,24,3,1,-62.45,53.65,-63.57,54.83,4}; -- Goblintown Throne Room 0x410d980e (800x600)
	tmpMapInfo[107]={107,270,"GaranStuff/MoorMap/Maps/Parphad_Upper_Level.jpg",1024,768,594.3182,-31218,-600,38064,76,3,2,62.97,52.98,62.63,53.58,5}; -- Parphad Upper
	tmpMapInfo[108]={108,271,"GaranStuff/MoorMap/Maps/Parphad_Lower_Level.jpg",1024,768,602.7397,-31667,-601.7857,38175,76,3,2,63.12,52.76,62.47,54,5}; -- Parphad Lower
-- more Moria interiors
	tmpMapInfo[109]={109,274,"GaranStuff/MoorMap/Maps/ThePeacefulPath.jpg",1024,768,605.6604,-33464,-604.5455,32562,35,3,2,53.37,55.7,53.08,56.46,5}; -- The Peaceful Path
	tmpMapInfo[110]={110,275,"GaranStuff/MoorMap/Maps/Ghar-khafush.jpg",1024,768,297.2222,-16114,-301.9231,16948,35,3,2,55.45,55.37,54.24,56.39,5}; -- Ghar-khafush
	tmpMapInfo[111]={111,276,"GaranStuff/MoorMap/Maps/Buzun-ghar.jpg",1024,768,300,-16362,-301.0870,8061,35,3,2,26.05,55.64,24.92,56.83,5}; -- Buzun-ghar
-- RoR Wildermore
	tmpMapInfo[112]={112,277,0x411375af,1024,768,38.7719,3009.2,-38.6233,-1044.19,71,1,2,-27.1,-77.7,-45.4,-53.9,4,0x411375a9,0x411375ad}; -- Wildermore
	tmpMapInfo[113]={113,278,0x411379ff,1024,768,334.7517,20914,-334.9282297,-12542,112,1,2,-37.5,-62.5,-39.8,-59.5,5,0x41137a01,0x411379fd}; -- Forlaw
-- RoR Westemnet
	tmpMapInfo[114]={114,287,0x4113C325,1024,768,19.40299,1892,-19.3191,-760,30,1,2,-39.3,-97.6,-79.0,-44.8,3,0x41142C46,0x41142C4b};
	tmpMapInfo[115]={115,288,0x4113C31F,1024,768,30.91317,2678,-30.9563,-1575,114,1,2,-50.9,-86.6,-75.6,-53.6,4,0x41142C3D,0x41142C4F}; --kingstead
	tmpMapInfo[116]={116,289,0x4113C320,1024,768,64.03197,4997,-63.6986,-2646,114,1,2,-41.6,-78.1,-53.5,-62.1,4,0x41142C4E,0x41142C3F}; -- broadacres
	tmpMapInfo[117]={117,290,0x4113C321,1024,768,45.08133,3202,-45.3157,-2719,114,1,2,-60.0,-71.0,-77.0,-48.4,4,0x41142C42,0x41142C3C}; -- eastfold
	tmpMapInfo[118]={118,291,0x4113C322,1024,768,50.08547,4464,-49.842,-2196,114,1,2,-44.1,-89.2,-59.4,-68.7,4,0x41142C51,0x41142C3E}; -- stonedeans
	tmpMapInfo[119]={119,292,0x4113C323,1024,768,119.3396,11134,-118.373,-7141,114,1,2,-60.3,-93.3,-66.8,-84.7,4,0x41142C38,0x41142C4D}; -- helm's deep
	tmpMapInfo[120]={120,293,0x4113C324,1024,768,45.26823,4306,-45.1091,-2366,114,1,2,-52.5,-95.2,-69.4,-72.5,4,0x41142C52,0x41142C55}; -- westfold
	tmpMapInfo[121]={121,294,0x4113C31E,1024,768,129.0462,9921,-129.122,-7510,115,1,2,-58.2,-76.9,-64.1,-69.0,5,0x41142C3A,0x41142C54}; -- edoras
	

	if tmpAnnotations==nil then tmpAnnotations={} end

	local tmpIndex;
	local tmpElem;
	if iconInfo==nil then iconInfo={} end
	-- remove all of the prior iconInfo records and load the tmpIconInfo records
	while #iconInfo>0 do
		table.remove(iconInfo,1);
	end
	for tmpIndex=1,#tmpIconInfo do
		iconInfo[#iconInfo+1]={tmpIconInfo[tmpIndex][1],tmpIconInfo[tmpIndex][2],tmpIconInfo[tmpIndex][3],tmpIconInfo[tmpIndex][4],tmpIconInfo[tmpIndex][5],tmpIconInfo[tmpIndex][6]};
	end

	if mapInfo==nil then mapInfo={} end
	while #mapInfo>0 do
		table.remove(mapInfo,1);
	end
	for tmpIndex=1,#tmpMapInfo do
		mapInfo[tmpIndex]={};
		for tmpElem=1,#tmpMapInfo[tmpIndex] do
			mapInfo[tmpIndex][tmpElem]=tmpMapInfo[tmpIndex][tmpElem];
		end
	end

	PatchDataSave( Turbine.DataScope.Account, "MM_IconInfo", iconInfo);
	PatchDataSave( Turbine.DataScope.Account, "MM_MapInfo", mapInfo);

end

function ProcessMap(tmpWorld)
	local result,error;
	local success,retval;
	_G.tmpAnnotations=nil
	_G.tmpMapString=nil
	if statusWindow.MapIndex==1 and statusWindow.WorldIndex>0 then
		result,error=loadstring("import \"GaranStuff.MoorMap.Data.MapData_"..statusWindow.MapIndex.."_"..worldNames[statusWindow.WorldIndex].."\"");
	else
		result,error=loadstring("import \"GaranStuff.MoorMap.Data.MapData_"..statusWindow.MapIndex.."\"");
	end
	if result==nil then
		Turbine.Shell.WriteLine("Error:"..tostring(error));
	else
		-- we may not have a data file for all maps (some have no annotations)
		success,retval=pcall(result);
		if success then
			if _G.tmpAnnotations~=nil then
				if statusWindow.MapIndex==1 and statusWindow.WorldIndex>0 then
					GaranStuff.MoorMap.PatchDataSave( Turbine.DataScope.Account, "MM_MapAnnotations_"..tostring(statusWindow.MapIndex).."_"..worldNames[statusWindow.WorldIndex],_G.tmpAnnotations);
					GaranStuff.MoorMap.PatchDataSave( Turbine.DataScope.Account, "MM_MapStrings_"..tostring(statusWindow.MapIndex).."_"..worldNames[statusWindow.WorldIndex],_G.tmpMapString);
				else
					GaranStuff.MoorMap.PatchDataSave( Turbine.DataScope.Account, "MM_MapAnnotations_"..tostring(statusWindow.MapIndex),_G.tmpAnnotations);
					GaranStuff.MoorMap.PatchDataSave( Turbine.DataScope.Account, "MM_MapStrings_"..tostring(statusWindow.MapIndex),_G.tmpMapString);
				end
			end
			return retval;
		else
			Turbine.Shell.WriteLine("Error:"..tostring(retval))
			return nil;
		end
	end
end

LoadDefaults(); -- need to have the mapInfo loaded before we instantiate the display

statusWindow=Turbine.UI.Lotro.Window();

statusWindow:SetSize(400,100);
statusWindow:SetPosition((Turbine.UI.Display:GetWidth() - statusWindow:GetWidth())/2,(Turbine.UI.Display:GetHeight() - statusWindow:GetHeight())/2)
statusWindow:SetZOrder(statusWindow:GetZOrder()+1); -- pop us in front
statusWindow:SetText("MoorMap Defaults");
statusWindow.Status="Loading";
statusWindow.StatusText=Turbine.UI.Label();
statusWindow.StatusText:SetParent(statusWindow);
statusWindow.StatusText:SetSize(200,18);
statusWindow.StatusText:SetPosition((statusWindow:GetWidth()-statusWindow.StatusText:GetWidth())/2,40);
statusWindow.StatusText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
statusWindow.StatusText:SetText(statusWindow.Status);

statusWindow.MapText=Turbine.UI.Label();
statusWindow.MapText:SetParent(statusWindow);
statusWindow.MapText:SetSize(200,18);
statusWindow.MapText:SetPosition((statusWindow:GetWidth()-statusWindow.MapText:GetWidth())/2,60);
statusWindow.MapText:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);

statusWindow:SetWantsUpdates(true);
statusWindow.MapIndex=1;
statusWindow.WorldIndex=0;

-- retrieve the "language" setting that was last saved (default is English if it was never saved)
local tmpSettings=PatchDataLoad(Turbine.DataScope.Account, "MoorMapSettings");
local index;
if (tmpSettings~=nil) then
	if tostring(type(tmpSettings))=="table" then
		for index=1,#tmpSettings do
			if tostring(type(tmpSettings[index]))=="table" then
				if (tmpSettings[index][1]=="language") then
					if tonumber(tmpSettings[index][2])~=nil then
						language=tonumber(tmpSettings[index][2]);
					end
				end
			end
		end
	end
end

statusWindow.Update=function()
	if (Plugins["MoorMapDefaults"] ~= nil) and statusWindow.Status=="Loading" then
		statusWindow.Status="Initializing";
		Plugins["MoorMapDefaults"].Unload = function(statusWindow,sender,args)
			Turbine.PluginManager.UnloadScriptState("MoorMapTerminator"); -- terminate the script that terminates us. how touching :)
		end
	elseif statusWindow.Status=="Initializing" then
		statusWindow.Status="Processing"
	elseif statusWindow.Status=="Processing" then
		if statusWindow.MapIndex==1 then
			if statusWindow.WorldIndex==0 then
				-- process the generic "Ettenmoors" data -- this MUST be processed first since the world specific string indexes depend on this
				statusWindow.MapText:SetText(Resource[language][mapInfo[statusWindow.MapIndex][2]]);
				ProcessMap();
				statusWindow.WorldIndex=1;
			elseif statusWindow.WorldIndex<#worldNames then
				-- process the world specific Ettenmoors data
				statusWindow.MapText:SetText("Ettenmoors:"..worldNames[statusWindow.WorldIndex]);
				ProcessMap(worldNames[statusWindow.WorldIndex]);
				statusWindow.WorldIndex=statusWindow.WorldIndex+1;
			else
				-- allow processing to fall through to other maps
				statusWindow.MapIndex=2;
			end
		else
			if statusWindow.MapIndex>#mapInfo then
				statusWindow.Status="Terminating"
				_G.tmpAnnotations=nil
				_G.tmpMapString=nil
			else
				statusWindow.MapText:SetText(Resource[language][mapInfo[statusWindow.MapIndex][2]]);
				ProcessMap();
				statusWindow.MapIndex=statusWindow.MapIndex+1
			end
		end
	elseif statusWindow.Status=="Terminating" then
		statusWindow:SetWantsUpdates(false);
		Turbine.PluginManager.LoadPlugin("MoorMapTerminator");
	end		
	statusWindow.StatusText:SetText(statusWindow.Status);
end
statusWindow:SetZOrder(statusWindow:GetZOrder()+1);
statusWindow:SetVisible(true);
